@@ -76,18 +76,14 @@ class PermissionValidationMeView(APIView):
 
     **Example Request**
 
-    POST /api/authz/v1/permissions/validate/me
-
-    .. code-block:: json
+    POST /api/authz/v1/permissions/validate/me::
 
         [
             {"action": "edit_library", "scope": "lib:DemoX:CSPROB"},
             {"action": "delete_library_content", "scope": "lib:OpenedX:CS50"}
         ]
 
-    **Example Response**
-
-    .. code-block:: json
+    **Example Response**::
 
         [
             {"action": "edit_library", "scope": "lib:DemoX:CSPROB", "allowed": true},
@@ -115,16 +111,13 @@ class PermissionValidationMeView(APIView):
                 action = perm["action"]
                 scope = perm["scope"]
                 allowed = api.is_user_allowed(username, action, scope)
-                response_data.append(
-                    {
-                        "action": action,
-                        "scope": scope,
-                        "allowed": allowed,
-                    }
-                )
+                response_data.append({"action": action, "scope": scope, "allowed": allowed})
             except ValueError as e:
                 logger.error(f"Error validating permission for user {username}: {e}")
-                return Response(data={"message": "Invalid scope format"}, status=status.HTTP_400_BAD_REQUEST)
+                return Response(
+                    data={"message": "Invalid scope format"},
+                    status=status.HTTP_400_BAD_REQUEST,
+                )
             except Exception as e:  # pylint: disable=broad-exception-caught
                 logger.error(f"Error validating permission for user {username}: {e}")
                 return Response(
@@ -178,9 +171,7 @@ class RoleUserAPIView(APIView):
 
     **Response Format (GET)**
 
-    Returns HTTP 200 OK with:
-
-    .. code-block:: json
+    Returns HTTP 200 OK with::
 
         {
             "count": 2,
@@ -204,9 +195,7 @@ class RoleUserAPIView(APIView):
 
     **Response Format (PUT)**
 
-    Returns HTTP 207 Multi-Status with:
-
-    .. code-block:: json
+    Returns HTTP 207 Multi-Status with::
 
         {
             "completed": [{"user_identifier": "john_doe", "status": "role_added"}],
@@ -215,9 +204,7 @@ class RoleUserAPIView(APIView):
 
     **Response Format (DELETE)**
 
-    Returns HTTP 207 Multi-Status with:
-
-    .. code-block:: json
+    Returns HTTP 207 Multi-Status with::
 
         {
             "completed": [{"user_identifier": "john_doe", "status": "role_removed"}],
@@ -233,9 +220,7 @@ class RoleUserAPIView(APIView):
 
     GET /api/authz/v1/roles/users/?scope=lib:DemoX:CSPROB&search=john&roles=library_admin
 
-    PUT /api/authz/v1/roles/users/
-
-    .. code-block:: json
+    PUT /api/authz/v1/roles/users/ ::
 
         {
             "role": "library_admin",
@@ -326,7 +311,9 @@ class RoleUserAPIView(APIView):
     @apidocs.schema(
         parameters=[
             apidocs.query_parameter(
-                "users", str, description="List of user identifiers (username or email) separated by a comma"
+                "users",
+                str,
+                description="List of user identifiers (username or email) separated by a comma",
             ),
             apidocs.query_parameter("role", str, description="The role to remove the users from"),
             apidocs.query_parameter("scope", str, description="The scope to remove the users from"),
@@ -404,9 +391,7 @@ class RoleListView(APIView):
 
     GET /api/authz/v1/roles/?scope=lib:OpenedX:CSPROB&page=1&page_size=10
 
-    **Example Response**
-
-    .. code-block:: json
+    **Example Response**::
 
         {
             "count": 2,
