@@ -21,11 +21,6 @@ def plugin_settings(settings):
     if casbin_adapter_app not in settings.INSTALLED_APPS:
         settings.INSTALLED_APPS.append(casbin_adapter_app)
     # Add Casbin configuration
-    settings.CASBIN_MODEL = os.path.join(
-        ROOT_DIRECTORY, "engine", "config", "model.conf"
-    )
-    settings.CASBIN_WATCHER_ENABLED = False
-    # TODO: Replace with a more dynamic configuration
-    # Redis host and port are temporarily loaded here for the MVP
-    settings.REDIS_HOST = "redis"
-    settings.REDIS_PORT = 6379
+    settings.CASBIN_MODEL = os.path.join(ROOT_DIRECTORY, "engine", "config", "model.conf")
+    if not hasattr(settings, "CASBIN_AUTO_LOAD_POLICY_INTERVAL"):
+        settings.CASBIN_AUTO_LOAD_POLICY_INTERVAL = 5
