@@ -93,8 +93,22 @@ class BaseRolesTestCase(TestCase):
         to add their specific role assignments by calling _assign_roles_to_users.
         """
         super().setUpClass()
+        AuthzEnforcer.get_enforcer().stop_auto_load_policy()
+        # Enable auto-save to ensure policies are saved to the database
+        # This is necessary because the tests are not using auto-load policy
+        AuthzEnforcer.get_enforcer().enable_auto_save(True)
         cls._seed_database_with_policies()
 
+    def setUp(self):
+        """Set up test environment."""
+        super().setUp()
+        AuthzEnforcer.get_enforcer().load_policy()  # Load policies before each test to simulate fresh start
+
+    def tearDown(self):
+        """Clean up after each test to ensure isolation."""
+        super().tearDown()
+        AuthzEnforcer.get_enforcer().clear_policy()  # Clear policies after each test to ensure isolation
+
 
 class RolesTestSetupMixin(BaseRolesTestCase):
     """Test case with comprehensive role assignments for general roles testing."""
@@ -230,16 +244,6 @@ class RolesTestSetupMixin(BaseRolesTestCase):
         ]
         cls._assign_roles_to_users(assignments=assignments)
 
-    def setUp(self):
-        """Set up test environment."""
-        super().setUp()
-        AuthzEnforcer.get_enforcer().load_policy()  # Load policies before each test to simulate fresh start
-
-    def tearDown(self):
-        """Clean up after each test to ensure isolation."""
-        super().tearDown()
-        AuthzEnforcer.get_enforcer().clear_policy()  # Clear policies after each test to ensure isolation
-
 
 @ddt
 class TestRolesAPI(RolesTestSetupMixin):
@@ -296,9 +300,7 @@ class TestRolesAPI(RolesTestSetupMixin):
             - Permissions are correctly retrieved for the given roles and scope.
             - The permissions match the expected permissions.
         """
-        assigned_permissions = get_permissions_for_single_role(
-            RoleData(external_key=role_name)
-        )
+        assigned_permissions = get_permissions_for_single_role(RoleData(external_key=role_name))
 
         self.assertEqual(assigned_permissions, expected_permissions)
 
@@ -323,9 +325,7 @@ class TestRolesAPI(RolesTestSetupMixin):
         ),
     )
     @unpack
-    def test_get_permissions_for_active_role_in_specific_scope(
-        self, role_name, scope_name, expected_permissions
-    ):
+    def test_get_permissions_for_active_role_in_specific_scope(self, role_name, scope_name, expected_permissions):
         """Test retrieving permissions for a specific role after role assignments.
 
         Expected result:
@@ -399,9 +399,7 @@ class TestRolesAPI(RolesTestSetupMixin):
         ("non_existent_user", "lib:Org999:non_existent_scope", set()),
     )
     @unpack
-    def test_get_subject_role_assignments_in_scope(
-        self, subject_name, scope_name, expected_roles
-    ):
+    def test_get_subject_role_assignments_in_scope(self, subject_name, scope_name, expected_roles):
         """Test retrieving roles assigned to a subject in a specific scope.
 
         Expected result:
@@ -460,19 +458,13 @@ class TestRolesAPI(RolesTestSetupMixin):
             - All roles assigned to the subject across all scopes are correctly retrieved.
             - Each role includes its associated permissions.
         """
-        role_assignments = get_subject_role_assignments(
-            SubjectData(external_key=subject_name)
-        )
+        role_assignments = get_subject_role_assignments(SubjectData(external_key=subject_name))
 
         self.assertEqual(len(role_assignments), len(expected_roles))
         for expected_role in expected_roles:
             # Compare the role part of the assignment
-            found = any(
-                expected_role in assignment.roles for assignment in role_assignments
-            )
-            self.assertTrue(
-                found, f"Expected role {expected_role} not found in assignments"
-            )
+            found = any(expected_role in assignment.roles for assignment in role_assignments)
+            self.assertTrue(found, f"Expected role {expected_role} not found in assignments")
 
     @ddt_data(
         ("library_admin", "lib:Org1:math_101", 1),
@@ -547,9 +539,7 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
         ("oliver", "library_admin", "lib:Org1:math_101", False),
     )
     @unpack
-    def test_batch_assign_role_to_subjects_in_scope(
-        self, subject_names, role, scope_name, batch
-    ):
+    def test_batch_assign_role_to_subjects_in_scope(self, subject_names, role, scope_name, batch):
         """Test assigning a role to a single or multiple subjects in a specific scope.
 
         Expected result:
@@ -568,7 +558,8 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
             )
             for subject_name in subject_names:
                 user_roles = get_subject_role_assignments_in_scope(
-                    SubjectData(external_key=subject_name), ScopeData(external_key=scope_name)
+                    SubjectData(external_key=subject_name),
+                    ScopeData(external_key=scope_name),
                 )
                 role_names = {r.external_key for assignment in user_roles for r in assignment.roles}
                 self.assertIn(role, role_names)
@@ -606,9 +597,7 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
         ("oliver", "library_admin", "lib:Org1:math_101", False),
     )
     @unpack
-    def test_unassign_role_from_subject_in_scope(
-        self, subject_names, role, scope_name, batch
-    ):
+    def test_unassign_role_from_subject_in_scope(self, subject_names, role, scope_name, batch):
         """Test unassigning a role from a subject or multiple subjects in a specific scope.
 
         Expected result:
@@ -648,10 +637,12 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
             [
                 RoleAssignmentData(
                     subject=SubjectData(external_key="alice"),
-                    roles=[RoleData(
-                        external_key="library_admin",
-                        permissions=LIST_LIBRARY_ADMIN_PERMISSIONS,
-                    )],
+                    roles=[
+                        RoleData(
+                            external_key="library_admin",
+                            permissions=LIST_LIBRARY_ADMIN_PERMISSIONS,
+                        )
+                    ],
                     scope=ScopeData(external_key="lib:Org1:math_101"),
                 )
             ],
@@ -661,10 +652,12 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
             [
                 RoleAssignmentData(
                     subject=SubjectData(external_key="bob"),
-                    roles=[RoleData(
-                        external_key="library_author",
-                        permissions=LIST_LIBRARY_AUTHOR_PERMISSIONS,
-                    )],
+                    roles=[
+                        RoleData(
+                            external_key="library_author",
+                            permissions=LIST_LIBRARY_AUTHOR_PERMISSIONS,
+                        )
+                    ],
                     scope=ScopeData(external_key="lib:Org1:history_201"),
                 )
             ],
@@ -674,10 +667,12 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
             [
                 RoleAssignmentData(
                     subject=SubjectData(external_key="carol"),
-                    roles=[RoleData(
-                        external_key="library_contributor",
-                        permissions=LIST_LIBRARY_CONTRIBUTOR_PERMISSIONS,
-                    )],
+                    roles=[
+                        RoleData(
+                            external_key="library_contributor",
+                            permissions=LIST_LIBRARY_CONTRIBUTOR_PERMISSIONS,
+                        )
+                    ],
                     scope=ScopeData(external_key="lib:Org1:science_301"),
                 )
             ],
@@ -687,10 +682,12 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
             [
                 RoleAssignmentData(
                     subject=SubjectData(external_key="dave"),
-                    roles=[RoleData(
-                        external_key="library_user",
-                        permissions=LIST_LIBRARY_USER_PERMISSIONS,
-                    )],
+                    roles=[
+                        RoleData(
+                            external_key="library_user",
+                            permissions=LIST_LIBRARY_USER_PERMISSIONS,
+                        )
+                    ],
                     scope=ScopeData(external_key="lib:Org1:english_101"),
                 )
             ],
@@ -705,9 +702,7 @@ class TestRoleAssignmentAPI(RolesTestSetupMixin):
             - All role assignments in the specified scope are correctly retrieved.
             - Each assignment includes the subject, role, and scope information with permissions.
         """
-        role_assignments = get_all_subject_role_assignments_in_scope(
-            ScopeData(external_key=scope_name)
-        )
+        role_assignments = get_all_subject_role_assignments_in_scope(ScopeData(external_key=scope_name))
 
         self.assertEqual(len(role_assignments), len(expected_assignments))
         for assignment in role_assignments:
